import * as pulumi from "@pulumi/pulumi";
export declare class Action extends pulumi.CustomResource {
    /**
     * Get an existing Action resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ActionState, opts?: pulumi.CustomResourceOptions): Action;
    /**
     * Returns true if the given object is an instance of Action.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Action;
    /**
     * when true, the next action will be called even if this action fails
     */
    readonly allowedToFail: pulumi.Output<boolean>;
    readonly name: pulumi.Output<string>;
    /**
     * ID of the organization
     */
    readonly orgId: pulumi.Output<string | undefined>;
    readonly script: pulumi.Output<string>;
    /**
     * the state of the action
     */
    readonly state: pulumi.Output<number>;
    /**
     * after which time the action will be terminated if not finished
     */
    readonly timeout: pulumi.Output<string>;
    /**
     * Create a Action resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ActionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Action resources.
 */
export interface ActionState {
    /**
     * when true, the next action will be called even if this action fails
     */
    allowedToFail?: pulumi.Input<boolean>;
    name?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    script?: pulumi.Input<string>;
    /**
     * the state of the action
     */
    state?: pulumi.Input<number>;
    /**
     * after which time the action will be terminated if not finished
     */
    timeout?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Action resource.
 */
export interface ActionArgs {
    /**
     * when true, the next action will be called even if this action fails
     */
    allowedToFail: pulumi.Input<boolean>;
    name?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    script: pulumi.Input<string>;
    /**
     * after which time the action will be terminated if not finished
     */
    timeout: pulumi.Input<string>;
}
