import * as pulumi from "@pulumi/pulumi";
export declare class ApplicationApi extends pulumi.CustomResource {
    /**
     * Get an existing ApplicationApi resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ApplicationApiState, opts?: pulumi.CustomResourceOptions): ApplicationApi;
    /**
     * Returns true if the given object is an instance of ApplicationApi.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ApplicationApi;
    /**
     * Auth method type, supported values: API_AUTH_METHOD_TYPE_BASIC, API_AUTH_METHOD_TYPE_PRIVATE_KEY_JWT
     */
    readonly authMethodType: pulumi.Output<string | undefined>;
    /**
     * generated ID for this config
     */
    readonly clientId: pulumi.Output<string>;
    /**
     * generated secret for this config
     */
    readonly clientSecret: pulumi.Output<string>;
    /**
     * Name of the application
     */
    readonly name: pulumi.Output<string>;
    /**
     * ID of the organization
     */
    readonly orgId: pulumi.Output<string | undefined>;
    /**
     * ID of the project
     */
    readonly projectId: pulumi.Output<string>;
    /**
     * Create a ApplicationApi resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApplicationApiArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ApplicationApi resources.
 */
export interface ApplicationApiState {
    /**
     * Auth method type, supported values: API_AUTH_METHOD_TYPE_BASIC, API_AUTH_METHOD_TYPE_PRIVATE_KEY_JWT
     */
    authMethodType?: pulumi.Input<string>;
    /**
     * generated ID for this config
     */
    clientId?: pulumi.Input<string>;
    /**
     * generated secret for this config
     */
    clientSecret?: pulumi.Input<string>;
    /**
     * Name of the application
     */
    name?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * ID of the project
     */
    projectId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ApplicationApi resource.
 */
export interface ApplicationApiArgs {
    /**
     * Auth method type, supported values: API_AUTH_METHOD_TYPE_BASIC, API_AUTH_METHOD_TYPE_PRIVATE_KEY_JWT
     */
    authMethodType?: pulumi.Input<string>;
    /**
     * Name of the application
     */
    name?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * ID of the project
     */
    projectId: pulumi.Input<string>;
}
