import * as pulumi from "@pulumi/pulumi";
export declare class ApplicationKey extends pulumi.CustomResource {
    /**
     * Get an existing ApplicationKey resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ApplicationKeyState, opts?: pulumi.CustomResourceOptions): ApplicationKey;
    /**
     * Returns true if the given object is an instance of ApplicationKey.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ApplicationKey;
    /**
     * ID of the application
     */
    readonly appId: pulumi.Output<string>;
    /**
     * Expiration date of the app key in the RFC3339 format
     */
    readonly expirationDate: pulumi.Output<string>;
    /**
     * Value of the app key
     */
    readonly keyDetails: pulumi.Output<string>;
    /**
     * Type of the app key, supported values: KEY_TYPE_UNSPECIFIED, KEY_TYPE_JSON
     */
    readonly keyType: pulumi.Output<string>;
    /**
     * ID of the organization
     */
    readonly orgId: pulumi.Output<string | undefined>;
    /**
     * ID of the project
     */
    readonly projectId: pulumi.Output<string>;
    /**
     * Create a ApplicationKey resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApplicationKeyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ApplicationKey resources.
 */
export interface ApplicationKeyState {
    /**
     * ID of the application
     */
    appId?: pulumi.Input<string>;
    /**
     * Expiration date of the app key in the RFC3339 format
     */
    expirationDate?: pulumi.Input<string>;
    /**
     * Value of the app key
     */
    keyDetails?: pulumi.Input<string>;
    /**
     * Type of the app key, supported values: KEY_TYPE_UNSPECIFIED, KEY_TYPE_JSON
     */
    keyType?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * ID of the project
     */
    projectId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ApplicationKey resource.
 */
export interface ApplicationKeyArgs {
    /**
     * ID of the application
     */
    appId: pulumi.Input<string>;
    /**
     * Expiration date of the app key in the RFC3339 format
     */
    expirationDate: pulumi.Input<string>;
    /**
     * Type of the app key, supported values: KEY_TYPE_UNSPECIFIED, KEY_TYPE_JSON
     */
    keyType: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * ID of the project
     */
    projectId: pulumi.Input<string>;
}
