import * as pulumi from "@pulumi/pulumi";
export declare class ApplicationOidc extends pulumi.CustomResource {
    /**
     * Get an existing ApplicationOidc resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ApplicationOidcState, opts?: pulumi.CustomResourceOptions): ApplicationOidc;
    /**
     * Returns true if the given object is an instance of ApplicationOidc.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ApplicationOidc;
    /**
     * Access token role assertion
     */
    readonly accessTokenRoleAssertion: pulumi.Output<boolean | undefined>;
    /**
     * Access token type, supported values: OIDC_TOKEN_TYPE_BEARER, OIDC_TOKEN_TYPE_JWT
     */
    readonly accessTokenType: pulumi.Output<string | undefined>;
    /**
     * Additional origins
     */
    readonly additionalOrigins: pulumi.Output<string[] | undefined>;
    /**
     * App type, supported values: OIDC_APP_TYPE_WEB, OIDC_APP_TYPE_USER_AGENT, OIDC_APP_TYPE_NATIVE
     */
    readonly appType: pulumi.Output<string | undefined>;
    /**
     * Auth method type, supported values: OIDC_AUTH_METHOD_TYPE_BASIC, OIDC_AUTH_METHOD_TYPE_POST, OIDC_AUTH_METHOD_TYPE_NONE,
     * OIDC_AUTH_METHOD_TYPE_PRIVATE_KEY_JWT
     */
    readonly authMethodType: pulumi.Output<string | undefined>;
    /**
     * generated ID for this config
     */
    readonly clientId: pulumi.Output<string>;
    /**
     * generated secret for this config
     */
    readonly clientSecret: pulumi.Output<string>;
    /**
     * Clockskew
     */
    readonly clockSkew: pulumi.Output<string | undefined>;
    /**
     * Dev mode
     */
    readonly devMode: pulumi.Output<boolean | undefined>;
    /**
     * Grant types, supported values: OIDC_GRANT_TYPE_AUTHORIZATION_CODE, OIDC_GRANT_TYPE_IMPLICIT,
     * OIDC_GRANT_TYPE_REFRESH_TOKEN, OIDC_GRANT_TYPE_DEVICE_CODE, OIDC_GRANT_TYPE_TOKEN_EXCHANGE
     */
    readonly grantTypes: pulumi.Output<string[]>;
    /**
     * ID token role assertion
     */
    readonly idTokenRoleAssertion: pulumi.Output<boolean | undefined>;
    /**
     * Token userinfo assertion
     */
    readonly idTokenUserinfoAssertion: pulumi.Output<boolean | undefined>;
    /**
     * Name of the application
     */
    readonly name: pulumi.Output<string>;
    /**
     * ID of the organization
     */
    readonly orgId: pulumi.Output<string | undefined>;
    /**
     * Post logout redirect URIs
     */
    readonly postLogoutRedirectUris: pulumi.Output<string[] | undefined>;
    /**
     * ID of the project
     */
    readonly projectId: pulumi.Output<string>;
    /**
     * RedirectURIs
     */
    readonly redirectUris: pulumi.Output<string[]>;
    /**
     * Response type, supported values: OIDC_RESPONSE_TYPE_CODE, OIDC_RESPONSE_TYPE_ID_TOKEN, OIDC_RESPONSE_TYPE_ID_TOKEN_TOKEN
     */
    readonly responseTypes: pulumi.Output<string[]>;
    /**
     * Version, supported values: OIDC_VERSION_1_0
     */
    readonly version: pulumi.Output<string | undefined>;
    /**
     * Create a ApplicationOidc resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApplicationOidcArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ApplicationOidc resources.
 */
export interface ApplicationOidcState {
    /**
     * Access token role assertion
     */
    accessTokenRoleAssertion?: pulumi.Input<boolean>;
    /**
     * Access token type, supported values: OIDC_TOKEN_TYPE_BEARER, OIDC_TOKEN_TYPE_JWT
     */
    accessTokenType?: pulumi.Input<string>;
    /**
     * Additional origins
     */
    additionalOrigins?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * App type, supported values: OIDC_APP_TYPE_WEB, OIDC_APP_TYPE_USER_AGENT, OIDC_APP_TYPE_NATIVE
     */
    appType?: pulumi.Input<string>;
    /**
     * Auth method type, supported values: OIDC_AUTH_METHOD_TYPE_BASIC, OIDC_AUTH_METHOD_TYPE_POST, OIDC_AUTH_METHOD_TYPE_NONE,
     * OIDC_AUTH_METHOD_TYPE_PRIVATE_KEY_JWT
     */
    authMethodType?: pulumi.Input<string>;
    /**
     * generated ID for this config
     */
    clientId?: pulumi.Input<string>;
    /**
     * generated secret for this config
     */
    clientSecret?: pulumi.Input<string>;
    /**
     * Clockskew
     */
    clockSkew?: pulumi.Input<string>;
    /**
     * Dev mode
     */
    devMode?: pulumi.Input<boolean>;
    /**
     * Grant types, supported values: OIDC_GRANT_TYPE_AUTHORIZATION_CODE, OIDC_GRANT_TYPE_IMPLICIT,
     * OIDC_GRANT_TYPE_REFRESH_TOKEN, OIDC_GRANT_TYPE_DEVICE_CODE, OIDC_GRANT_TYPE_TOKEN_EXCHANGE
     */
    grantTypes?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * ID token role assertion
     */
    idTokenRoleAssertion?: pulumi.Input<boolean>;
    /**
     * Token userinfo assertion
     */
    idTokenUserinfoAssertion?: pulumi.Input<boolean>;
    /**
     * Name of the application
     */
    name?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * Post logout redirect URIs
     */
    postLogoutRedirectUris?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * ID of the project
     */
    projectId?: pulumi.Input<string>;
    /**
     * RedirectURIs
     */
    redirectUris?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Response type, supported values: OIDC_RESPONSE_TYPE_CODE, OIDC_RESPONSE_TYPE_ID_TOKEN, OIDC_RESPONSE_TYPE_ID_TOKEN_TOKEN
     */
    responseTypes?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Version, supported values: OIDC_VERSION_1_0
     */
    version?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ApplicationOidc resource.
 */
export interface ApplicationOidcArgs {
    /**
     * Access token role assertion
     */
    accessTokenRoleAssertion?: pulumi.Input<boolean>;
    /**
     * Access token type, supported values: OIDC_TOKEN_TYPE_BEARER, OIDC_TOKEN_TYPE_JWT
     */
    accessTokenType?: pulumi.Input<string>;
    /**
     * Additional origins
     */
    additionalOrigins?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * App type, supported values: OIDC_APP_TYPE_WEB, OIDC_APP_TYPE_USER_AGENT, OIDC_APP_TYPE_NATIVE
     */
    appType?: pulumi.Input<string>;
    /**
     * Auth method type, supported values: OIDC_AUTH_METHOD_TYPE_BASIC, OIDC_AUTH_METHOD_TYPE_POST, OIDC_AUTH_METHOD_TYPE_NONE,
     * OIDC_AUTH_METHOD_TYPE_PRIVATE_KEY_JWT
     */
    authMethodType?: pulumi.Input<string>;
    /**
     * Clockskew
     */
    clockSkew?: pulumi.Input<string>;
    /**
     * Dev mode
     */
    devMode?: pulumi.Input<boolean>;
    /**
     * Grant types, supported values: OIDC_GRANT_TYPE_AUTHORIZATION_CODE, OIDC_GRANT_TYPE_IMPLICIT,
     * OIDC_GRANT_TYPE_REFRESH_TOKEN, OIDC_GRANT_TYPE_DEVICE_CODE, OIDC_GRANT_TYPE_TOKEN_EXCHANGE
     */
    grantTypes: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * ID token role assertion
     */
    idTokenRoleAssertion?: pulumi.Input<boolean>;
    /**
     * Token userinfo assertion
     */
    idTokenUserinfoAssertion?: pulumi.Input<boolean>;
    /**
     * Name of the application
     */
    name?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * Post logout redirect URIs
     */
    postLogoutRedirectUris?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * ID of the project
     */
    projectId: pulumi.Input<string>;
    /**
     * RedirectURIs
     */
    redirectUris: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Response type, supported values: OIDC_RESPONSE_TYPE_CODE, OIDC_RESPONSE_TYPE_ID_TOKEN, OIDC_RESPONSE_TYPE_ID_TOKEN_TOKEN
     */
    responseTypes: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Version, supported values: OIDC_VERSION_1_0
     */
    version?: pulumi.Input<string>;
}
