import * as pulumi from "@pulumi/pulumi";
export declare class DefaultLoginPolicy extends pulumi.CustomResource {
    /**
     * Get an existing DefaultLoginPolicy resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: DefaultLoginPolicyState, opts?: pulumi.CustomResourceOptions): DefaultLoginPolicy;
    /**
     * Returns true if the given object is an instance of DefaultLoginPolicy.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DefaultLoginPolicy;
    /**
     * if set to true, the suffix (@domain.com) of an unknown username input on the login screen will be matched against the
     * org domains and will redirect to the registration of that organisation on success.
     */
    readonly allowDomainDiscovery: pulumi.Output<boolean | undefined>;
    /**
     * defines if a user is allowed to add a defined identity provider. E.g. Google auth
     */
    readonly allowExternalIdp: pulumi.Output<boolean>;
    /**
     * defines if a person is allowed to register a user on this organisation
     */
    readonly allowRegister: pulumi.Output<boolean>;
    /**
     * defines where the user will be redirected to if the login is started without app context (e.g. from mail)
     */
    readonly defaultRedirectUri: pulumi.Output<string>;
    /**
     * defines if user can additionally (to the loginname) be identified by their verified email address
     */
    readonly disableLoginWithEmail: pulumi.Output<boolean | undefined>;
    /**
     * defines if user can additionally (to the loginname) be identified by their verified phone number
     */
    readonly disableLoginWithPhone: pulumi.Output<boolean | undefined>;
    readonly externalLoginCheckLifetime: pulumi.Output<string>;
    /**
     * defines if a user MUST use a multi factor to log in
     */
    readonly forceMfa: pulumi.Output<boolean>;
    /**
     * if activated, ZITADEL only enforces MFA on local authentications. On authentications through MFA, ZITADEL won't prompt
     * for MFA.
     */
    readonly forceMfaLocalOnly: pulumi.Output<boolean>;
    /**
     * defines if password reset link should be shown in the login screen
     */
    readonly hidePasswordReset: pulumi.Output<boolean>;
    /**
     * allowed idps to login or register
     */
    readonly idps: pulumi.Output<string[] | undefined>;
    /**
     * defines if unknown username on login screen directly return an error or always display the password screen
     */
    readonly ignoreUnknownUsernames: pulumi.Output<boolean>;
    readonly mfaInitSkipLifetime: pulumi.Output<string>;
    readonly multiFactorCheckLifetime: pulumi.Output<string>;
    /**
     * allowed multi factors
     */
    readonly multiFactors: pulumi.Output<string[] | undefined>;
    readonly passwordCheckLifetime: pulumi.Output<string>;
    /**
     * defines if passwordless is allowed for users
     */
    readonly passwordlessType: pulumi.Output<string>;
    readonly secondFactorCheckLifetime: pulumi.Output<string>;
    /**
     * allowed second factors
     */
    readonly secondFactors: pulumi.Output<string[] | undefined>;
    /**
     * defines if a user is allowed to login with his username and password
     */
    readonly userLogin: pulumi.Output<boolean>;
    /**
     * Create a DefaultLoginPolicy resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DefaultLoginPolicyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering DefaultLoginPolicy resources.
 */
export interface DefaultLoginPolicyState {
    /**
     * if set to true, the suffix (@domain.com) of an unknown username input on the login screen will be matched against the
     * org domains and will redirect to the registration of that organisation on success.
     */
    allowDomainDiscovery?: pulumi.Input<boolean>;
    /**
     * defines if a user is allowed to add a defined identity provider. E.g. Google auth
     */
    allowExternalIdp?: pulumi.Input<boolean>;
    /**
     * defines if a person is allowed to register a user on this organisation
     */
    allowRegister?: pulumi.Input<boolean>;
    /**
     * defines where the user will be redirected to if the login is started without app context (e.g. from mail)
     */
    defaultRedirectUri?: pulumi.Input<string>;
    /**
     * defines if user can additionally (to the loginname) be identified by their verified email address
     */
    disableLoginWithEmail?: pulumi.Input<boolean>;
    /**
     * defines if user can additionally (to the loginname) be identified by their verified phone number
     */
    disableLoginWithPhone?: pulumi.Input<boolean>;
    externalLoginCheckLifetime?: pulumi.Input<string>;
    /**
     * defines if a user MUST use a multi factor to log in
     */
    forceMfa?: pulumi.Input<boolean>;
    /**
     * if activated, ZITADEL only enforces MFA on local authentications. On authentications through MFA, ZITADEL won't prompt
     * for MFA.
     */
    forceMfaLocalOnly?: pulumi.Input<boolean>;
    /**
     * defines if password reset link should be shown in the login screen
     */
    hidePasswordReset?: pulumi.Input<boolean>;
    /**
     * allowed idps to login or register
     */
    idps?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * defines if unknown username on login screen directly return an error or always display the password screen
     */
    ignoreUnknownUsernames?: pulumi.Input<boolean>;
    mfaInitSkipLifetime?: pulumi.Input<string>;
    multiFactorCheckLifetime?: pulumi.Input<string>;
    /**
     * allowed multi factors
     */
    multiFactors?: pulumi.Input<pulumi.Input<string>[]>;
    passwordCheckLifetime?: pulumi.Input<string>;
    /**
     * defines if passwordless is allowed for users
     */
    passwordlessType?: pulumi.Input<string>;
    secondFactorCheckLifetime?: pulumi.Input<string>;
    /**
     * allowed second factors
     */
    secondFactors?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * defines if a user is allowed to login with his username and password
     */
    userLogin?: pulumi.Input<boolean>;
}
/**
 * The set of arguments for constructing a DefaultLoginPolicy resource.
 */
export interface DefaultLoginPolicyArgs {
    /**
     * if set to true, the suffix (@domain.com) of an unknown username input on the login screen will be matched against the
     * org domains and will redirect to the registration of that organisation on success.
     */
    allowDomainDiscovery?: pulumi.Input<boolean>;
    /**
     * defines if a user is allowed to add a defined identity provider. E.g. Google auth
     */
    allowExternalIdp: pulumi.Input<boolean>;
    /**
     * defines if a person is allowed to register a user on this organisation
     */
    allowRegister: pulumi.Input<boolean>;
    /**
     * defines where the user will be redirected to if the login is started without app context (e.g. from mail)
     */
    defaultRedirectUri: pulumi.Input<string>;
    /**
     * defines if user can additionally (to the loginname) be identified by their verified email address
     */
    disableLoginWithEmail?: pulumi.Input<boolean>;
    /**
     * defines if user can additionally (to the loginname) be identified by their verified phone number
     */
    disableLoginWithPhone?: pulumi.Input<boolean>;
    externalLoginCheckLifetime: pulumi.Input<string>;
    /**
     * defines if a user MUST use a multi factor to log in
     */
    forceMfa: pulumi.Input<boolean>;
    /**
     * if activated, ZITADEL only enforces MFA on local authentications. On authentications through MFA, ZITADEL won't prompt
     * for MFA.
     */
    forceMfaLocalOnly: pulumi.Input<boolean>;
    /**
     * defines if password reset link should be shown in the login screen
     */
    hidePasswordReset: pulumi.Input<boolean>;
    /**
     * allowed idps to login or register
     */
    idps?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * defines if unknown username on login screen directly return an error or always display the password screen
     */
    ignoreUnknownUsernames: pulumi.Input<boolean>;
    mfaInitSkipLifetime: pulumi.Input<string>;
    multiFactorCheckLifetime: pulumi.Input<string>;
    /**
     * allowed multi factors
     */
    multiFactors?: pulumi.Input<pulumi.Input<string>[]>;
    passwordCheckLifetime: pulumi.Input<string>;
    /**
     * defines if passwordless is allowed for users
     */
    passwordlessType: pulumi.Input<string>;
    secondFactorCheckLifetime: pulumi.Input<string>;
    /**
     * allowed second factors
     */
    secondFactors?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * defines if a user is allowed to login with his username and password
     */
    userLogin: pulumi.Input<boolean>;
}
