import * as pulumi from "@pulumi/pulumi";
export declare class Domain extends pulumi.CustomResource {
    /**
     * Get an existing Domain resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: DomainState, opts?: pulumi.CustomResourceOptions): Domain;
    /**
     * Returns true if the given object is an instance of Domain.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Domain;
    /**
     * Is domain primary
     */
    readonly isPrimary: pulumi.Output<boolean | undefined>;
    /**
     * Is domain verified
     */
    readonly isVerified: pulumi.Output<boolean>;
    /**
     * Name of the domain
     */
    readonly name: pulumi.Output<string>;
    /**
     * ID of the organization
     */
    readonly orgId: pulumi.Output<string | undefined>;
    /**
     * Validation type
     */
    readonly validationType: pulumi.Output<number>;
    /**
     * Create a Domain resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: DomainArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Domain resources.
 */
export interface DomainState {
    /**
     * Is domain primary
     */
    isPrimary?: pulumi.Input<boolean>;
    /**
     * Is domain verified
     */
    isVerified?: pulumi.Input<boolean>;
    /**
     * Name of the domain
     */
    name?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * Validation type
     */
    validationType?: pulumi.Input<number>;
}
/**
 * The set of arguments for constructing a Domain resource.
 */
export interface DomainArgs {
    /**
     * Is domain primary
     */
    isPrimary?: pulumi.Input<boolean>;
    /**
     * Name of the domain
     */
    name?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
}
