import * as pulumi from "@pulumi/pulumi";
export declare class DomainPolicy extends pulumi.CustomResource {
    /**
     * Get an existing DomainPolicy resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: DomainPolicyState, opts?: pulumi.CustomResourceOptions): DomainPolicy;
    /**
     * Returns true if the given object is an instance of DomainPolicy.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DomainPolicy;
    /**
     * ID of the organization
     */
    readonly orgId: pulumi.Output<string | undefined>;
    readonly smtpSenderAddressMatchesInstanceDomain: pulumi.Output<boolean>;
    /**
     * User login must be domain
     */
    readonly userLoginMustBeDomain: pulumi.Output<boolean>;
    /**
     * Validate organization domains
     */
    readonly validateOrgDomains: pulumi.Output<boolean>;
    /**
     * Create a DomainPolicy resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DomainPolicyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering DomainPolicy resources.
 */
export interface DomainPolicyState {
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    smtpSenderAddressMatchesInstanceDomain?: pulumi.Input<boolean>;
    /**
     * User login must be domain
     */
    userLoginMustBeDomain?: pulumi.Input<boolean>;
    /**
     * Validate organization domains
     */
    validateOrgDomains?: pulumi.Input<boolean>;
}
/**
 * The set of arguments for constructing a DomainPolicy resource.
 */
export interface DomainPolicyArgs {
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    smtpSenderAddressMatchesInstanceDomain: pulumi.Input<boolean>;
    /**
     * User login must be domain
     */
    userLoginMustBeDomain: pulumi.Input<boolean>;
    /**
     * Validate organization domains
     */
    validateOrgDomains: pulumi.Input<boolean>;
}
