import * as pulumi from "@pulumi/pulumi";
export declare class HumanUser extends pulumi.CustomResource {
    /**
     * Get an existing HumanUser resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: HumanUserState, opts?: pulumi.CustomResourceOptions): HumanUser;
    /**
     * Returns true if the given object is an instance of HumanUser.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is HumanUser;
    /**
     * Display name of the user
     */
    readonly displayName: pulumi.Output<string>;
    /**
     * Email of the user
     */
    readonly email: pulumi.Output<string>;
    /**
     * First name of the user
     */
    readonly firstName: pulumi.Output<string>;
    /**
     * Gender of the user, supported values: GENDER_UNSPECIFIED, GENDER_FEMALE, GENDER_MALE, GENDER_DIVERSE
     */
    readonly gender: pulumi.Output<string | undefined>;
    /**
     * Initially set password for the user, not changeable after creation
     */
    readonly initialPassword: pulumi.Output<string | undefined>;
    /**
     * Is the email verified of the user, can only be true if password of the user is set
     */
    readonly isEmailVerified: pulumi.Output<boolean | undefined>;
    /**
     * Is the phone verified of the user
     */
    readonly isPhoneVerified: pulumi.Output<boolean | undefined>;
    /**
     * Last name of the user
     */
    readonly lastName: pulumi.Output<string>;
    /**
     * Loginnames
     */
    readonly loginNames: pulumi.Output<string[]>;
    /**
     * Nick name of the user
     */
    readonly nickName: pulumi.Output<string | undefined>;
    /**
     * ID of the organization
     */
    readonly orgId: pulumi.Output<string | undefined>;
    /**
     * Phone of the user
     */
    readonly phone: pulumi.Output<string | undefined>;
    /**
     * Preferred language of the user
     */
    readonly preferredLanguage: pulumi.Output<string | undefined>;
    /**
     * Preferred login name
     */
    readonly preferredLoginName: pulumi.Output<string>;
    /**
     * State of the user
     */
    readonly state: pulumi.Output<string>;
    /**
     * Username
     */
    readonly userName: pulumi.Output<string>;
    /**
     * Create a HumanUser resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: HumanUserArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering HumanUser resources.
 */
export interface HumanUserState {
    /**
     * Display name of the user
     */
    displayName?: pulumi.Input<string>;
    /**
     * Email of the user
     */
    email?: pulumi.Input<string>;
    /**
     * First name of the user
     */
    firstName?: pulumi.Input<string>;
    /**
     * Gender of the user, supported values: GENDER_UNSPECIFIED, GENDER_FEMALE, GENDER_MALE, GENDER_DIVERSE
     */
    gender?: pulumi.Input<string>;
    /**
     * Initially set password for the user, not changeable after creation
     */
    initialPassword?: pulumi.Input<string>;
    /**
     * Is the email verified of the user, can only be true if password of the user is set
     */
    isEmailVerified?: pulumi.Input<boolean>;
    /**
     * Is the phone verified of the user
     */
    isPhoneVerified?: pulumi.Input<boolean>;
    /**
     * Last name of the user
     */
    lastName?: pulumi.Input<string>;
    /**
     * Loginnames
     */
    loginNames?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Nick name of the user
     */
    nickName?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * Phone of the user
     */
    phone?: pulumi.Input<string>;
    /**
     * Preferred language of the user
     */
    preferredLanguage?: pulumi.Input<string>;
    /**
     * Preferred login name
     */
    preferredLoginName?: pulumi.Input<string>;
    /**
     * State of the user
     */
    state?: pulumi.Input<string>;
    /**
     * Username
     */
    userName?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a HumanUser resource.
 */
export interface HumanUserArgs {
    /**
     * Display name of the user
     */
    displayName?: pulumi.Input<string>;
    /**
     * Email of the user
     */
    email: pulumi.Input<string>;
    /**
     * First name of the user
     */
    firstName: pulumi.Input<string>;
    /**
     * Gender of the user, supported values: GENDER_UNSPECIFIED, GENDER_FEMALE, GENDER_MALE, GENDER_DIVERSE
     */
    gender?: pulumi.Input<string>;
    /**
     * Initially set password for the user, not changeable after creation
     */
    initialPassword?: pulumi.Input<string>;
    /**
     * Is the email verified of the user, can only be true if password of the user is set
     */
    isEmailVerified?: pulumi.Input<boolean>;
    /**
     * Is the phone verified of the user
     */
    isPhoneVerified?: pulumi.Input<boolean>;
    /**
     * Last name of the user
     */
    lastName: pulumi.Input<string>;
    /**
     * Nick name of the user
     */
    nickName?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * Phone of the user
     */
    phone?: pulumi.Input<string>;
    /**
     * Preferred language of the user
     */
    preferredLanguage?: pulumi.Input<string>;
    /**
     * Username
     */
    userName: pulumi.Input<string>;
}
