import * as pulumi from "@pulumi/pulumi";
export declare class IdpGitlabSelfHosted extends pulumi.CustomResource {
    /**
     * Get an existing IdpGitlabSelfHosted resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: IdpGitlabSelfHostedState, opts?: pulumi.CustomResourceOptions): IdpGitlabSelfHosted;
    /**
     * Returns true if the given object is an instance of IdpGitlabSelfHosted.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IdpGitlabSelfHosted;
    /**
     * client id generated by the identity provider
     */
    readonly clientId: pulumi.Output<string>;
    /**
     * client secret generated by the identity provider
     */
    readonly clientSecret: pulumi.Output<string>;
    /**
     * enable if a new account in ZITADEL should be created automatically on login with an external account
     */
    readonly isAutoCreation: pulumi.Output<boolean>;
    /**
     * enable if a the ZITADEL account fields should be updated automatically on each login
     */
    readonly isAutoUpdate: pulumi.Output<boolean>;
    /**
     * enable if users should be able to create a new account in ZITADEL when using an external account
     */
    readonly isCreationAllowed: pulumi.Output<boolean>;
    /**
     * enable if users should be able to link an existing ZITADEL user with an external account
     */
    readonly isLinkingAllowed: pulumi.Output<boolean>;
    /**
     * the providers issuer
     */
    readonly issuer: pulumi.Output<string>;
    /**
     * Name of the IDP
     */
    readonly name: pulumi.Output<string>;
    /**
     * the scopes requested by ZITADEL during the request on the identity provider
     */
    readonly scopes: pulumi.Output<string[] | undefined>;
    /**
     * Create a IdpGitlabSelfHosted resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IdpGitlabSelfHostedArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering IdpGitlabSelfHosted resources.
 */
export interface IdpGitlabSelfHostedState {
    /**
     * client id generated by the identity provider
     */
    clientId?: pulumi.Input<string>;
    /**
     * client secret generated by the identity provider
     */
    clientSecret?: pulumi.Input<string>;
    /**
     * enable if a new account in ZITADEL should be created automatically on login with an external account
     */
    isAutoCreation?: pulumi.Input<boolean>;
    /**
     * enable if a the ZITADEL account fields should be updated automatically on each login
     */
    isAutoUpdate?: pulumi.Input<boolean>;
    /**
     * enable if users should be able to create a new account in ZITADEL when using an external account
     */
    isCreationAllowed?: pulumi.Input<boolean>;
    /**
     * enable if users should be able to link an existing ZITADEL user with an external account
     */
    isLinkingAllowed?: pulumi.Input<boolean>;
    /**
     * the providers issuer
     */
    issuer?: pulumi.Input<string>;
    /**
     * Name of the IDP
     */
    name?: pulumi.Input<string>;
    /**
     * the scopes requested by ZITADEL during the request on the identity provider
     */
    scopes?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The set of arguments for constructing a IdpGitlabSelfHosted resource.
 */
export interface IdpGitlabSelfHostedArgs {
    /**
     * client id generated by the identity provider
     */
    clientId: pulumi.Input<string>;
    /**
     * client secret generated by the identity provider
     */
    clientSecret: pulumi.Input<string>;
    /**
     * enable if a new account in ZITADEL should be created automatically on login with an external account
     */
    isAutoCreation: pulumi.Input<boolean>;
    /**
     * enable if a the ZITADEL account fields should be updated automatically on each login
     */
    isAutoUpdate: pulumi.Input<boolean>;
    /**
     * enable if users should be able to create a new account in ZITADEL when using an external account
     */
    isCreationAllowed: pulumi.Input<boolean>;
    /**
     * enable if users should be able to link an existing ZITADEL user with an external account
     */
    isLinkingAllowed: pulumi.Input<boolean>;
    /**
     * the providers issuer
     */
    issuer: pulumi.Input<string>;
    /**
     * Name of the IDP
     */
    name?: pulumi.Input<string>;
    /**
     * the scopes requested by ZITADEL during the request on the identity provider
     */
    scopes?: pulumi.Input<pulumi.Input<string>[]>;
}
