import * as pulumi from "@pulumi/pulumi";
export declare class IdpLdap extends pulumi.CustomResource {
    /**
     * Get an existing IdpLdap resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: IdpLdapState, opts?: pulumi.CustomResourceOptions): IdpLdap;
    /**
     * Returns true if the given object is an instance of IdpLdap.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IdpLdap;
    /**
     * User attribute for the avatar url
     */
    readonly avatarUrlAttribute: pulumi.Output<string | undefined>;
    /**
     * Base DN for LDAP connections
     */
    readonly baseDn: pulumi.Output<string>;
    /**
     * Bind DN for LDAP connections
     */
    readonly bindDn: pulumi.Output<string>;
    /**
     * Bind password for LDAP connections
     */
    readonly bindPassword: pulumi.Output<string>;
    /**
     * User attribute for the display name
     */
    readonly displayNameAttribute: pulumi.Output<string | undefined>;
    /**
     * User attribute for the email
     */
    readonly emailAttribute: pulumi.Output<string | undefined>;
    /**
     * User attribute for the email verified state
     */
    readonly emailVerifiedAttribute: pulumi.Output<string | undefined>;
    /**
     * User attribute for the first name
     */
    readonly firstNameAttribute: pulumi.Output<string | undefined>;
    /**
     * User attribute for the id
     */
    readonly idAttribute: pulumi.Output<string | undefined>;
    /**
     * enable if a new account in ZITADEL should be created automatically on login with an external account
     */
    readonly isAutoCreation: pulumi.Output<boolean>;
    /**
     * enable if a the ZITADEL account fields should be updated automatically on each login
     */
    readonly isAutoUpdate: pulumi.Output<boolean>;
    /**
     * enable if users should be able to create a new account in ZITADEL when using an external account
     */
    readonly isCreationAllowed: pulumi.Output<boolean>;
    /**
     * enable if users should be able to link an existing ZITADEL user with an external account
     */
    readonly isLinkingAllowed: pulumi.Output<boolean>;
    /**
     * User attribute for the last name
     */
    readonly lastNameAttribute: pulumi.Output<string | undefined>;
    /**
     * Name of the IDP
     */
    readonly name: pulumi.Output<string>;
    /**
     * User attribute for the nick name
     */
    readonly nickNameAttribute: pulumi.Output<string | undefined>;
    /**
     * User attribute for the phone
     */
    readonly phoneAttribute: pulumi.Output<string | undefined>;
    /**
     * User attribute for the phone verified state
     */
    readonly phoneVerifiedAttribute: pulumi.Output<string | undefined>;
    /**
     * User attribute for the preferred language
     */
    readonly preferredLanguageAttribute: pulumi.Output<string | undefined>;
    /**
     * User attribute for the preferred username
     */
    readonly preferredUsernameAttribute: pulumi.Output<string | undefined>;
    /**
     * User attribute for the profile
     */
    readonly profileAttribute: pulumi.Output<string | undefined>;
    /**
     * Servers to try in order for establishing LDAP connections
     */
    readonly servers: pulumi.Output<string[]>;
    /**
     * Wether to use StartTLS for LDAP connections
     */
    readonly startTls: pulumi.Output<boolean>;
    /**
     * Timeout for LDAP connections
     */
    readonly timeout: pulumi.Output<string>;
    /**
     * User base for LDAP connections
     */
    readonly userBase: pulumi.Output<string>;
    /**
     * User filters for LDAP connections
     */
    readonly userFilters: pulumi.Output<string[]>;
    /**
     * User object classes for LDAP connections
     */
    readonly userObjectClasses: pulumi.Output<string[]>;
    /**
     * Create a IdpLdap resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IdpLdapArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering IdpLdap resources.
 */
export interface IdpLdapState {
    /**
     * User attribute for the avatar url
     */
    avatarUrlAttribute?: pulumi.Input<string>;
    /**
     * Base DN for LDAP connections
     */
    baseDn?: pulumi.Input<string>;
    /**
     * Bind DN for LDAP connections
     */
    bindDn?: pulumi.Input<string>;
    /**
     * Bind password for LDAP connections
     */
    bindPassword?: pulumi.Input<string>;
    /**
     * User attribute for the display name
     */
    displayNameAttribute?: pulumi.Input<string>;
    /**
     * User attribute for the email
     */
    emailAttribute?: pulumi.Input<string>;
    /**
     * User attribute for the email verified state
     */
    emailVerifiedAttribute?: pulumi.Input<string>;
    /**
     * User attribute for the first name
     */
    firstNameAttribute?: pulumi.Input<string>;
    /**
     * User attribute for the id
     */
    idAttribute?: pulumi.Input<string>;
    /**
     * enable if a new account in ZITADEL should be created automatically on login with an external account
     */
    isAutoCreation?: pulumi.Input<boolean>;
    /**
     * enable if a the ZITADEL account fields should be updated automatically on each login
     */
    isAutoUpdate?: pulumi.Input<boolean>;
    /**
     * enable if users should be able to create a new account in ZITADEL when using an external account
     */
    isCreationAllowed?: pulumi.Input<boolean>;
    /**
     * enable if users should be able to link an existing ZITADEL user with an external account
     */
    isLinkingAllowed?: pulumi.Input<boolean>;
    /**
     * User attribute for the last name
     */
    lastNameAttribute?: pulumi.Input<string>;
    /**
     * Name of the IDP
     */
    name?: pulumi.Input<string>;
    /**
     * User attribute for the nick name
     */
    nickNameAttribute?: pulumi.Input<string>;
    /**
     * User attribute for the phone
     */
    phoneAttribute?: pulumi.Input<string>;
    /**
     * User attribute for the phone verified state
     */
    phoneVerifiedAttribute?: pulumi.Input<string>;
    /**
     * User attribute for the preferred language
     */
    preferredLanguageAttribute?: pulumi.Input<string>;
    /**
     * User attribute for the preferred username
     */
    preferredUsernameAttribute?: pulumi.Input<string>;
    /**
     * User attribute for the profile
     */
    profileAttribute?: pulumi.Input<string>;
    /**
     * Servers to try in order for establishing LDAP connections
     */
    servers?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Wether to use StartTLS for LDAP connections
     */
    startTls?: pulumi.Input<boolean>;
    /**
     * Timeout for LDAP connections
     */
    timeout?: pulumi.Input<string>;
    /**
     * User base for LDAP connections
     */
    userBase?: pulumi.Input<string>;
    /**
     * User filters for LDAP connections
     */
    userFilters?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * User object classes for LDAP connections
     */
    userObjectClasses?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The set of arguments for constructing a IdpLdap resource.
 */
export interface IdpLdapArgs {
    /**
     * User attribute for the avatar url
     */
    avatarUrlAttribute?: pulumi.Input<string>;
    /**
     * Base DN for LDAP connections
     */
    baseDn: pulumi.Input<string>;
    /**
     * Bind DN for LDAP connections
     */
    bindDn: pulumi.Input<string>;
    /**
     * Bind password for LDAP connections
     */
    bindPassword: pulumi.Input<string>;
    /**
     * User attribute for the display name
     */
    displayNameAttribute?: pulumi.Input<string>;
    /**
     * User attribute for the email
     */
    emailAttribute?: pulumi.Input<string>;
    /**
     * User attribute for the email verified state
     */
    emailVerifiedAttribute?: pulumi.Input<string>;
    /**
     * User attribute for the first name
     */
    firstNameAttribute?: pulumi.Input<string>;
    /**
     * User attribute for the id
     */
    idAttribute?: pulumi.Input<string>;
    /**
     * enable if a new account in ZITADEL should be created automatically on login with an external account
     */
    isAutoCreation: pulumi.Input<boolean>;
    /**
     * enable if a the ZITADEL account fields should be updated automatically on each login
     */
    isAutoUpdate: pulumi.Input<boolean>;
    /**
     * enable if users should be able to create a new account in ZITADEL when using an external account
     */
    isCreationAllowed: pulumi.Input<boolean>;
    /**
     * enable if users should be able to link an existing ZITADEL user with an external account
     */
    isLinkingAllowed: pulumi.Input<boolean>;
    /**
     * User attribute for the last name
     */
    lastNameAttribute?: pulumi.Input<string>;
    /**
     * Name of the IDP
     */
    name?: pulumi.Input<string>;
    /**
     * User attribute for the nick name
     */
    nickNameAttribute?: pulumi.Input<string>;
    /**
     * User attribute for the phone
     */
    phoneAttribute?: pulumi.Input<string>;
    /**
     * User attribute for the phone verified state
     */
    phoneVerifiedAttribute?: pulumi.Input<string>;
    /**
     * User attribute for the preferred language
     */
    preferredLanguageAttribute?: pulumi.Input<string>;
    /**
     * User attribute for the preferred username
     */
    preferredUsernameAttribute?: pulumi.Input<string>;
    /**
     * User attribute for the profile
     */
    profileAttribute?: pulumi.Input<string>;
    /**
     * Servers to try in order for establishing LDAP connections
     */
    servers: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Wether to use StartTLS for LDAP connections
     */
    startTls: pulumi.Input<boolean>;
    /**
     * Timeout for LDAP connections
     */
    timeout: pulumi.Input<string>;
    /**
     * User base for LDAP connections
     */
    userBase: pulumi.Input<string>;
    /**
     * User filters for LDAP connections
     */
    userFilters: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * User object classes for LDAP connections
     */
    userObjectClasses: pulumi.Input<pulumi.Input<string>[]>;
}
