import * as pulumi from "@pulumi/pulumi";
export declare class LabelPolicy extends pulumi.CustomResource {
    /**
     * Get an existing LabelPolicy resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: LabelPolicyState, opts?: pulumi.CustomResourceOptions): LabelPolicy;
    /**
     * Returns true if the given object is an instance of LabelPolicy.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LabelPolicy;
    /**
     * hex value for background color
     */
    readonly backgroundColor: pulumi.Output<string>;
    /**
     * hex value for background color dark theme
     */
    readonly backgroundColorDark: pulumi.Output<string>;
    /**
     * disable watermark
     */
    readonly disableWatermark: pulumi.Output<boolean>;
    /**
     * hex value for font color
     */
    readonly fontColor: pulumi.Output<string>;
    /**
     * hex value for font color dark theme
     */
    readonly fontColorDark: pulumi.Output<string>;
    readonly fontHash: pulumi.Output<string | undefined>;
    readonly fontPath: pulumi.Output<string | undefined>;
    readonly fontUrl: pulumi.Output<string>;
    /**
     * hides the org suffix on the login form if the scope "urn:zitadel:iam:org:domain:primary:{domainname}" is set. Details
     * about this scope in https://zitadel.com/docs/apis/openidoauth/scopes#reserved-scopes
     */
    readonly hideLoginNameSuffix: pulumi.Output<boolean>;
    readonly iconDarkHash: pulumi.Output<string | undefined>;
    readonly iconDarkPath: pulumi.Output<string | undefined>;
    readonly iconHash: pulumi.Output<string | undefined>;
    readonly iconPath: pulumi.Output<string | undefined>;
    readonly iconUrl: pulumi.Output<string>;
    readonly iconUrlDark: pulumi.Output<string>;
    readonly logoDarkHash: pulumi.Output<string | undefined>;
    readonly logoDarkPath: pulumi.Output<string | undefined>;
    readonly logoHash: pulumi.Output<string | undefined>;
    readonly logoPath: pulumi.Output<string | undefined>;
    readonly logoUrl: pulumi.Output<string>;
    readonly logoUrlDark: pulumi.Output<string>;
    /**
     * ID of the organization
     */
    readonly orgId: pulumi.Output<string | undefined>;
    /**
     * hex value for primary color
     */
    readonly primaryColor: pulumi.Output<string>;
    /**
     * hex value for primary color dark theme
     */
    readonly primaryColorDark: pulumi.Output<string>;
    /**
     * set the label policy active after creating/updating
     */
    readonly setActive: pulumi.Output<boolean | undefined>;
    /**
     * theme mode, supported values: THEME_MODE_UNSPECIFIED, THEME_MODE_AUTO, THEME_MODE_DARK, THEME_MODE_LIGHT
     */
    readonly themeMode: pulumi.Output<string | undefined>;
    /**
     * hex value for warn color
     */
    readonly warnColor: pulumi.Output<string>;
    /**
     * hex value for warn color dark theme
     */
    readonly warnColorDark: pulumi.Output<string>;
    /**
     * Create a LabelPolicy resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LabelPolicyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering LabelPolicy resources.
 */
export interface LabelPolicyState {
    /**
     * hex value for background color
     */
    backgroundColor?: pulumi.Input<string>;
    /**
     * hex value for background color dark theme
     */
    backgroundColorDark?: pulumi.Input<string>;
    /**
     * disable watermark
     */
    disableWatermark?: pulumi.Input<boolean>;
    /**
     * hex value for font color
     */
    fontColor?: pulumi.Input<string>;
    /**
     * hex value for font color dark theme
     */
    fontColorDark?: pulumi.Input<string>;
    fontHash?: pulumi.Input<string>;
    fontPath?: pulumi.Input<string>;
    fontUrl?: pulumi.Input<string>;
    /**
     * hides the org suffix on the login form if the scope "urn:zitadel:iam:org:domain:primary:{domainname}" is set. Details
     * about this scope in https://zitadel.com/docs/apis/openidoauth/scopes#reserved-scopes
     */
    hideLoginNameSuffix?: pulumi.Input<boolean>;
    iconDarkHash?: pulumi.Input<string>;
    iconDarkPath?: pulumi.Input<string>;
    iconHash?: pulumi.Input<string>;
    iconPath?: pulumi.Input<string>;
    iconUrl?: pulumi.Input<string>;
    iconUrlDark?: pulumi.Input<string>;
    logoDarkHash?: pulumi.Input<string>;
    logoDarkPath?: pulumi.Input<string>;
    logoHash?: pulumi.Input<string>;
    logoPath?: pulumi.Input<string>;
    logoUrl?: pulumi.Input<string>;
    logoUrlDark?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * hex value for primary color
     */
    primaryColor?: pulumi.Input<string>;
    /**
     * hex value for primary color dark theme
     */
    primaryColorDark?: pulumi.Input<string>;
    /**
     * set the label policy active after creating/updating
     */
    setActive?: pulumi.Input<boolean>;
    /**
     * theme mode, supported values: THEME_MODE_UNSPECIFIED, THEME_MODE_AUTO, THEME_MODE_DARK, THEME_MODE_LIGHT
     */
    themeMode?: pulumi.Input<string>;
    /**
     * hex value for warn color
     */
    warnColor?: pulumi.Input<string>;
    /**
     * hex value for warn color dark theme
     */
    warnColorDark?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a LabelPolicy resource.
 */
export interface LabelPolicyArgs {
    /**
     * hex value for background color
     */
    backgroundColor: pulumi.Input<string>;
    /**
     * hex value for background color dark theme
     */
    backgroundColorDark: pulumi.Input<string>;
    /**
     * disable watermark
     */
    disableWatermark: pulumi.Input<boolean>;
    /**
     * hex value for font color
     */
    fontColor: pulumi.Input<string>;
    /**
     * hex value for font color dark theme
     */
    fontColorDark: pulumi.Input<string>;
    fontHash?: pulumi.Input<string>;
    fontPath?: pulumi.Input<string>;
    /**
     * hides the org suffix on the login form if the scope "urn:zitadel:iam:org:domain:primary:{domainname}" is set. Details
     * about this scope in https://zitadel.com/docs/apis/openidoauth/scopes#reserved-scopes
     */
    hideLoginNameSuffix: pulumi.Input<boolean>;
    iconDarkHash?: pulumi.Input<string>;
    iconDarkPath?: pulumi.Input<string>;
    iconHash?: pulumi.Input<string>;
    iconPath?: pulumi.Input<string>;
    logoDarkHash?: pulumi.Input<string>;
    logoDarkPath?: pulumi.Input<string>;
    logoHash?: pulumi.Input<string>;
    logoPath?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * hex value for primary color
     */
    primaryColor: pulumi.Input<string>;
    /**
     * hex value for primary color dark theme
     */
    primaryColorDark: pulumi.Input<string>;
    /**
     * set the label policy active after creating/updating
     */
    setActive?: pulumi.Input<boolean>;
    /**
     * theme mode, supported values: THEME_MODE_UNSPECIFIED, THEME_MODE_AUTO, THEME_MODE_DARK, THEME_MODE_LIGHT
     */
    themeMode?: pulumi.Input<string>;
    /**
     * hex value for warn color
     */
    warnColor: pulumi.Input<string>;
    /**
     * hex value for warn color dark theme
     */
    warnColorDark: pulumi.Input<string>;
}
