import * as pulumi from "@pulumi/pulumi";
export declare class MachineUser extends pulumi.CustomResource {
    /**
     * Get an existing MachineUser resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: MachineUserState, opts?: pulumi.CustomResourceOptions): MachineUser;
    /**
     * Returns true if the given object is an instance of MachineUser.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is MachineUser;
    /**
     * Access token type, supported values: ACCESS_TOKEN_TYPE_BEARER, ACCESS_TOKEN_TYPE_JWT
     */
    readonly accessTokenType: pulumi.Output<string | undefined>;
    /**
     * Value of the client ID if withSecret is true
     */
    readonly clientId: pulumi.Output<string>;
    /**
     * Value of the client secret if withSecret is true
     */
    readonly clientSecret: pulumi.Output<string>;
    /**
     * Description of the user
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Loginnames
     */
    readonly loginNames: pulumi.Output<string[]>;
    /**
     * Name of the machine user
     */
    readonly name: pulumi.Output<string>;
    /**
     * ID of the organization
     */
    readonly orgId: pulumi.Output<string | undefined>;
    /**
     * Preferred login name
     */
    readonly preferredLoginName: pulumi.Output<string>;
    /**
     * State of the user
     */
    readonly state: pulumi.Output<string>;
    /**
     * Username
     */
    readonly userName: pulumi.Output<string>;
    /**
     * Generate machine secret, only applicable if creation or change from false
     */
    readonly withSecret: pulumi.Output<boolean | undefined>;
    /**
     * Create a MachineUser resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MachineUserArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering MachineUser resources.
 */
export interface MachineUserState {
    /**
     * Access token type, supported values: ACCESS_TOKEN_TYPE_BEARER, ACCESS_TOKEN_TYPE_JWT
     */
    accessTokenType?: pulumi.Input<string>;
    /**
     * Value of the client ID if withSecret is true
     */
    clientId?: pulumi.Input<string>;
    /**
     * Value of the client secret if withSecret is true
     */
    clientSecret?: pulumi.Input<string>;
    /**
     * Description of the user
     */
    description?: pulumi.Input<string>;
    /**
     * Loginnames
     */
    loginNames?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Name of the machine user
     */
    name?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * Preferred login name
     */
    preferredLoginName?: pulumi.Input<string>;
    /**
     * State of the user
     */
    state?: pulumi.Input<string>;
    /**
     * Username
     */
    userName?: pulumi.Input<string>;
    /**
     * Generate machine secret, only applicable if creation or change from false
     */
    withSecret?: pulumi.Input<boolean>;
}
/**
 * The set of arguments for constructing a MachineUser resource.
 */
export interface MachineUserArgs {
    /**
     * Access token type, supported values: ACCESS_TOKEN_TYPE_BEARER, ACCESS_TOKEN_TYPE_JWT
     */
    accessTokenType?: pulumi.Input<string>;
    /**
     * Description of the user
     */
    description?: pulumi.Input<string>;
    /**
     * Name of the machine user
     */
    name?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * Username
     */
    userName: pulumi.Input<string>;
    /**
     * Generate machine secret, only applicable if creation or change from false
     */
    withSecret?: pulumi.Input<boolean>;
}
