import * as pulumi from "@pulumi/pulumi";
export declare class OrgIdpJwt extends pulumi.CustomResource {
    /**
     * Get an existing OrgIdpJwt resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: OrgIdpJwtState, opts?: pulumi.CustomResourceOptions): OrgIdpJwt;
    /**
     * Returns true if the given object is an instance of OrgIdpJwt.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is OrgIdpJwt;
    /**
     * auto register for users from this idp
     */
    readonly autoRegister: pulumi.Output<boolean>;
    /**
     * the name of the header where the JWT is sent in, default is authorization
     */
    readonly headerName: pulumi.Output<string>;
    /**
     * the issuer of the jwt (for validation)
     */
    readonly issuer: pulumi.Output<string>;
    /**
     * the endpoint where the jwt can be extracted
     */
    readonly jwtEndpoint: pulumi.Output<string>;
    /**
     * the endpoint to the key (JWK) which are used to sign the JWT with
     */
    readonly keysEndpoint: pulumi.Output<string>;
    /**
     * Name of the IDP
     */
    readonly name: pulumi.Output<string>;
    /**
     * ID of the organization
     */
    readonly orgId: pulumi.Output<string | undefined>;
    /**
     * Some identity providers specify the styling of the button to their login, supported values: STYLING_TYPE_UNSPECIFIED,
     * STYLING_TYPE_GOOGLE
     */
    readonly stylingType: pulumi.Output<string>;
    /**
     * Create a OrgIdpJwt resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: OrgIdpJwtArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering OrgIdpJwt resources.
 */
export interface OrgIdpJwtState {
    /**
     * auto register for users from this idp
     */
    autoRegister?: pulumi.Input<boolean>;
    /**
     * the name of the header where the JWT is sent in, default is authorization
     */
    headerName?: pulumi.Input<string>;
    /**
     * the issuer of the jwt (for validation)
     */
    issuer?: pulumi.Input<string>;
    /**
     * the endpoint where the jwt can be extracted
     */
    jwtEndpoint?: pulumi.Input<string>;
    /**
     * the endpoint to the key (JWK) which are used to sign the JWT with
     */
    keysEndpoint?: pulumi.Input<string>;
    /**
     * Name of the IDP
     */
    name?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * Some identity providers specify the styling of the button to their login, supported values: STYLING_TYPE_UNSPECIFIED,
     * STYLING_TYPE_GOOGLE
     */
    stylingType?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a OrgIdpJwt resource.
 */
export interface OrgIdpJwtArgs {
    /**
     * auto register for users from this idp
     */
    autoRegister: pulumi.Input<boolean>;
    /**
     * the name of the header where the JWT is sent in, default is authorization
     */
    headerName: pulumi.Input<string>;
    /**
     * the issuer of the jwt (for validation)
     */
    issuer: pulumi.Input<string>;
    /**
     * the endpoint where the jwt can be extracted
     */
    jwtEndpoint: pulumi.Input<string>;
    /**
     * the endpoint to the key (JWK) which are used to sign the JWT with
     */
    keysEndpoint: pulumi.Input<string>;
    /**
     * Name of the IDP
     */
    name?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * Some identity providers specify the styling of the button to their login, supported values: STYLING_TYPE_UNSPECIFIED,
     * STYLING_TYPE_GOOGLE
     */
    stylingType: pulumi.Input<string>;
}
