import * as pulumi from "@pulumi/pulumi";
export declare class PasswordComplexityPolicy extends pulumi.CustomResource {
    /**
     * Get an existing PasswordComplexityPolicy resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: PasswordComplexityPolicyState, opts?: pulumi.CustomResourceOptions): PasswordComplexityPolicy;
    /**
     * Returns true if the given object is an instance of PasswordComplexityPolicy.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is PasswordComplexityPolicy;
    /**
     * defines if the password MUST contain a lower case letter
     */
    readonly hasLowercase: pulumi.Output<boolean>;
    /**
     * defines if the password MUST contain a number
     */
    readonly hasNumber: pulumi.Output<boolean>;
    /**
     * defines if the password MUST contain a symbol. E.g. "$"
     */
    readonly hasSymbol: pulumi.Output<boolean>;
    /**
     * defines if the password MUST contain an upper case letter
     */
    readonly hasUppercase: pulumi.Output<boolean>;
    /**
     * Minimal length for the password
     */
    readonly minLength: pulumi.Output<number>;
    /**
     * ID of the organization
     */
    readonly orgId: pulumi.Output<string | undefined>;
    /**
     * Create a PasswordComplexityPolicy resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: PasswordComplexityPolicyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering PasswordComplexityPolicy resources.
 */
export interface PasswordComplexityPolicyState {
    /**
     * defines if the password MUST contain a lower case letter
     */
    hasLowercase?: pulumi.Input<boolean>;
    /**
     * defines if the password MUST contain a number
     */
    hasNumber?: pulumi.Input<boolean>;
    /**
     * defines if the password MUST contain a symbol. E.g. "$"
     */
    hasSymbol?: pulumi.Input<boolean>;
    /**
     * defines if the password MUST contain an upper case letter
     */
    hasUppercase?: pulumi.Input<boolean>;
    /**
     * Minimal length for the password
     */
    minLength?: pulumi.Input<number>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a PasswordComplexityPolicy resource.
 */
export interface PasswordComplexityPolicyArgs {
    /**
     * defines if the password MUST contain a lower case letter
     */
    hasLowercase: pulumi.Input<boolean>;
    /**
     * defines if the password MUST contain a number
     */
    hasNumber: pulumi.Input<boolean>;
    /**
     * defines if the password MUST contain a symbol. E.g. "$"
     */
    hasSymbol: pulumi.Input<boolean>;
    /**
     * defines if the password MUST contain an upper case letter
     */
    hasUppercase: pulumi.Input<boolean>;
    /**
     * Minimal length for the password
     */
    minLength: pulumi.Input<number>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
}
