import * as pulumi from "@pulumi/pulumi";
export declare class PersonalAccessToken extends pulumi.CustomResource {
    /**
     * Get an existing PersonalAccessToken resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: PersonalAccessTokenState, opts?: pulumi.CustomResourceOptions): PersonalAccessToken;
    /**
     * Returns true if the given object is an instance of PersonalAccessToken.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is PersonalAccessToken;
    /**
     * Expiration date of the token in the RFC3339 format
     */
    readonly expirationDate: pulumi.Output<string | undefined>;
    /**
     * ID of the organization
     */
    readonly orgId: pulumi.Output<string | undefined>;
    /**
     * Value of the token
     */
    readonly token: pulumi.Output<string>;
    /**
     * ID of the user
     */
    readonly userId: pulumi.Output<string>;
    /**
     * Create a PersonalAccessToken resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: PersonalAccessTokenArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering PersonalAccessToken resources.
 */
export interface PersonalAccessTokenState {
    /**
     * Expiration date of the token in the RFC3339 format
     */
    expirationDate?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * Value of the token
     */
    token?: pulumi.Input<string>;
    /**
     * ID of the user
     */
    userId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a PersonalAccessToken resource.
 */
export interface PersonalAccessTokenArgs {
    /**
     * Expiration date of the token in the RFC3339 format
     */
    expirationDate?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * ID of the user
     */
    userId: pulumi.Input<string>;
}
