import * as pulumi from "@pulumi/pulumi";
export declare class Project extends pulumi.CustomResource {
    /**
     * Get an existing Project resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ProjectState, opts?: pulumi.CustomResourceOptions): Project;
    /**
     * Returns true if the given object is an instance of Project.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Project;
    /**
     * ZITADEL checks if the org of the user has permission to this project
     */
    readonly hasProjectCheck: pulumi.Output<boolean | undefined>;
    /**
     * Name of the project
     */
    readonly name: pulumi.Output<string>;
    /**
     * ID of the organization
     */
    readonly orgId: pulumi.Output<string | undefined>;
    /**
     * Defines from where the private labeling should be triggered, supported values: PRIVATE_LABELING_SETTING_UNSPECIFIED,
     * PRIVATE_LABELING_SETTING_ENFORCE_PROJECT_RESOURCE_OWNER_POLICY,
     * PRIVATE_LABELING_SETTING_ALLOW_LOGIN_USER_RESOURCE_OWNER_POLICY
     */
    readonly privateLabelingSetting: pulumi.Output<string | undefined>;
    /**
     * describes if roles of user should be added in token
     */
    readonly projectRoleAssertion: pulumi.Output<boolean | undefined>;
    /**
     * ZITADEL checks if the user has at least one on this project
     */
    readonly projectRoleCheck: pulumi.Output<boolean | undefined>;
    /**
     * State of the project
     */
    readonly state: pulumi.Output<string>;
    /**
     * Create a Project resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ProjectArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Project resources.
 */
export interface ProjectState {
    /**
     * ZITADEL checks if the org of the user has permission to this project
     */
    hasProjectCheck?: pulumi.Input<boolean>;
    /**
     * Name of the project
     */
    name?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * Defines from where the private labeling should be triggered, supported values: PRIVATE_LABELING_SETTING_UNSPECIFIED,
     * PRIVATE_LABELING_SETTING_ENFORCE_PROJECT_RESOURCE_OWNER_POLICY,
     * PRIVATE_LABELING_SETTING_ALLOW_LOGIN_USER_RESOURCE_OWNER_POLICY
     */
    privateLabelingSetting?: pulumi.Input<string>;
    /**
     * describes if roles of user should be added in token
     */
    projectRoleAssertion?: pulumi.Input<boolean>;
    /**
     * ZITADEL checks if the user has at least one on this project
     */
    projectRoleCheck?: pulumi.Input<boolean>;
    /**
     * State of the project
     */
    state?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Project resource.
 */
export interface ProjectArgs {
    /**
     * ZITADEL checks if the org of the user has permission to this project
     */
    hasProjectCheck?: pulumi.Input<boolean>;
    /**
     * Name of the project
     */
    name?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * Defines from where the private labeling should be triggered, supported values: PRIVATE_LABELING_SETTING_UNSPECIFIED,
     * PRIVATE_LABELING_SETTING_ENFORCE_PROJECT_RESOURCE_OWNER_POLICY,
     * PRIVATE_LABELING_SETTING_ALLOW_LOGIN_USER_RESOURCE_OWNER_POLICY
     */
    privateLabelingSetting?: pulumi.Input<string>;
    /**
     * describes if roles of user should be added in token
     */
    projectRoleAssertion?: pulumi.Input<boolean>;
    /**
     * ZITADEL checks if the user has at least one on this project
     */
    projectRoleCheck?: pulumi.Input<boolean>;
}
