import * as pulumi from "@pulumi/pulumi";
export declare class ProjectRole extends pulumi.CustomResource {
    /**
     * Get an existing ProjectRole resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ProjectRoleState, opts?: pulumi.CustomResourceOptions): ProjectRole;
    /**
     * Returns true if the given object is an instance of ProjectRole.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ProjectRole;
    /**
     * Name used for project role
     */
    readonly displayName: pulumi.Output<string>;
    /**
     * Group used for project role
     */
    readonly group: pulumi.Output<string | undefined>;
    /**
     * ID of the organization
     */
    readonly orgId: pulumi.Output<string | undefined>;
    /**
     * ID of the project
     */
    readonly projectId: pulumi.Output<string>;
    /**
     * Key used for project role
     */
    readonly roleKey: pulumi.Output<string>;
    /**
     * Create a ProjectRole resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ProjectRoleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ProjectRole resources.
 */
export interface ProjectRoleState {
    /**
     * Name used for project role
     */
    displayName?: pulumi.Input<string>;
    /**
     * Group used for project role
     */
    group?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * ID of the project
     */
    projectId?: pulumi.Input<string>;
    /**
     * Key used for project role
     */
    roleKey?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ProjectRole resource.
 */
export interface ProjectRoleArgs {
    /**
     * Name used for project role
     */
    displayName: pulumi.Input<string>;
    /**
     * Group used for project role
     */
    group?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * ID of the project
     */
    projectId: pulumi.Input<string>;
    /**
     * Key used for project role
     */
    roleKey: pulumi.Input<string>;
}
