import * as pulumi from "@pulumi/pulumi";
/**
 * The provider type for the zitadel package. By default, resources use package-wide configuration
 * settings, however an explicit `Provider` instance may be created and passed during resource
 * construction to achieve fine-grained programmatic control over provider settings. See the
 * [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.
 */
export declare class Provider extends pulumi.ProviderResource {
    /**
     * Returns true if the given object is an instance of Provider.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Provider;
    /**
     * Domain used to connect to the ZITADEL instance
     */
    readonly domain: pulumi.Output<string>;
    /**
     * Path to the file containing credentials to connect to ZITADEL. Either 'jwt_profile_file' or 'jwt_profile_json' is
     * required
     */
    readonly jwtProfileFile: pulumi.Output<string | undefined>;
    /**
     * JSON value of credentials to connect to ZITADEL. Either 'jwt_profile_file' or 'jwt_profile_json' is required
     */
    readonly jwtProfileJson: pulumi.Output<string | undefined>;
    /**
     * Used port if not the default ports 80 or 443 are configured
     */
    readonly port: pulumi.Output<string | undefined>;
    /**
     * Path to the file containing credentials to connect to ZITADEL
     */
    readonly token: pulumi.Output<string | undefined>;
    /**
     * Create a Provider resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ProviderArgs, opts?: pulumi.ResourceOptions);
}
/**
 * The set of arguments for constructing a Provider resource.
 */
export interface ProviderArgs {
    /**
     * Domain used to connect to the ZITADEL instance
     */
    domain: pulumi.Input<string>;
    /**
     * Use insecure connection
     */
    insecure?: pulumi.Input<boolean>;
    /**
     * Path to the file containing credentials to connect to ZITADEL. Either 'jwt_profile_file' or 'jwt_profile_json' is
     * required
     */
    jwtProfileFile?: pulumi.Input<string>;
    /**
     * JSON value of credentials to connect to ZITADEL. Either 'jwt_profile_file' or 'jwt_profile_json' is required
     */
    jwtProfileJson?: pulumi.Input<string>;
    /**
     * Used port if not the default ports 80 or 443 are configured
     */
    port?: pulumi.Input<string>;
    /**
     * Path to the file containing credentials to connect to ZITADEL
     */
    token?: pulumi.Input<string>;
}
