import * as pulumi from "@pulumi/pulumi";
export declare class SmtpConfig extends pulumi.CustomResource {
    /**
     * Get an existing SmtpConfig resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: SmtpConfigState, opts?: pulumi.CustomResourceOptions): SmtpConfig;
    /**
     * Returns true if the given object is an instance of SmtpConfig.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SmtpConfig;
    /**
     * Host and port address to your SMTP server.
     */
    readonly host: pulumi.Output<string>;
    /**
     * Password used to communicate with your SMTP server.
     */
    readonly password: pulumi.Output<string | undefined>;
    /**
     * Address to reply to.
     */
    readonly replyToAddress: pulumi.Output<string | undefined>;
    /**
     * Address used to send emails.
     */
    readonly senderAddress: pulumi.Output<string>;
    /**
     * Sender name used to send emails.
     */
    readonly senderName: pulumi.Output<string>;
    /**
     * Set the SMTP configuration active after creating/updating
     */
    readonly setActive: pulumi.Output<boolean | undefined>;
    /**
     * TLS used to communicate with your SMTP server.
     */
    readonly tls: pulumi.Output<boolean | undefined>;
    /**
     * User used to communicate with your SMTP server.
     */
    readonly user: pulumi.Output<string | undefined>;
    /**
     * Create a SmtpConfig resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SmtpConfigArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering SmtpConfig resources.
 */
export interface SmtpConfigState {
    /**
     * Host and port address to your SMTP server.
     */
    host?: pulumi.Input<string>;
    /**
     * Password used to communicate with your SMTP server.
     */
    password?: pulumi.Input<string>;
    /**
     * Address to reply to.
     */
    replyToAddress?: pulumi.Input<string>;
    /**
     * Address used to send emails.
     */
    senderAddress?: pulumi.Input<string>;
    /**
     * Sender name used to send emails.
     */
    senderName?: pulumi.Input<string>;
    /**
     * Set the SMTP configuration active after creating/updating
     */
    setActive?: pulumi.Input<boolean>;
    /**
     * TLS used to communicate with your SMTP server.
     */
    tls?: pulumi.Input<boolean>;
    /**
     * User used to communicate with your SMTP server.
     */
    user?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a SmtpConfig resource.
 */
export interface SmtpConfigArgs {
    /**
     * Host and port address to your SMTP server.
     */
    host: pulumi.Input<string>;
    /**
     * Password used to communicate with your SMTP server.
     */
    password?: pulumi.Input<string>;
    /**
     * Address to reply to.
     */
    replyToAddress?: pulumi.Input<string>;
    /**
     * Address used to send emails.
     */
    senderAddress: pulumi.Input<string>;
    /**
     * Sender name used to send emails.
     */
    senderName: pulumi.Input<string>;
    /**
     * Set the SMTP configuration active after creating/updating
     */
    setActive?: pulumi.Input<boolean>;
    /**
     * TLS used to communicate with your SMTP server.
     */
    tls?: pulumi.Input<boolean>;
    /**
     * User used to communicate with your SMTP server.
     */
    user?: pulumi.Input<string>;
}
