import * as pulumi from "@pulumi/pulumi";
export declare class TriggerActions extends pulumi.CustomResource {
    /**
     * Get an existing TriggerActions resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: TriggerActionsState, opts?: pulumi.CustomResourceOptions): TriggerActions;
    /**
     * Returns true if the given object is an instance of TriggerActions.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TriggerActions;
    /**
     * IDs of the triggered actions
     */
    readonly actionIds: pulumi.Output<string[]>;
    /**
     * Type of the flow to which the action triggers belong, supported values: FLOW_TYPE_EXTERNAL_AUTHENTICATION,
     * FLOW_TYPE_CUSTOMISE_TOKEN, FLOW_TYPE_INTERNAL_AUTHENTICATION, FLOW_TYPE_SAML_RESPONSE
     */
    readonly flowType: pulumi.Output<string>;
    /**
     * ID of the organization
     */
    readonly orgId: pulumi.Output<string | undefined>;
    /**
     * Trigger type on when the actions get triggered, supported values: TRIGGER_TYPE_POST_AUTHENTICATION,
     * TRIGGER_TYPE_PRE_CREATION, TRIGGER_TYPE_POST_CREATION, TRIGGER_TYPE_PRE_USERINFO_CREATION,
     * TRIGGER_TYPE_PRE_ACCESS_TOKEN_CREATION, TRIGGER_TYPE_PRE_SAML_RESPONSE_CREATION
     */
    readonly triggerType: pulumi.Output<string>;
    /**
     * Create a TriggerActions resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TriggerActionsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering TriggerActions resources.
 */
export interface TriggerActionsState {
    /**
     * IDs of the triggered actions
     */
    actionIds?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Type of the flow to which the action triggers belong, supported values: FLOW_TYPE_EXTERNAL_AUTHENTICATION,
     * FLOW_TYPE_CUSTOMISE_TOKEN, FLOW_TYPE_INTERNAL_AUTHENTICATION, FLOW_TYPE_SAML_RESPONSE
     */
    flowType?: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * Trigger type on when the actions get triggered, supported values: TRIGGER_TYPE_POST_AUTHENTICATION,
     * TRIGGER_TYPE_PRE_CREATION, TRIGGER_TYPE_POST_CREATION, TRIGGER_TYPE_PRE_USERINFO_CREATION,
     * TRIGGER_TYPE_PRE_ACCESS_TOKEN_CREATION, TRIGGER_TYPE_PRE_SAML_RESPONSE_CREATION
     */
    triggerType?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a TriggerActions resource.
 */
export interface TriggerActionsArgs {
    /**
     * IDs of the triggered actions
     */
    actionIds: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Type of the flow to which the action triggers belong, supported values: FLOW_TYPE_EXTERNAL_AUTHENTICATION,
     * FLOW_TYPE_CUSTOMISE_TOKEN, FLOW_TYPE_INTERNAL_AUTHENTICATION, FLOW_TYPE_SAML_RESPONSE
     */
    flowType: pulumi.Input<string>;
    /**
     * ID of the organization
     */
    orgId?: pulumi.Input<string>;
    /**
     * Trigger type on when the actions get triggered, supported values: TRIGGER_TYPE_POST_AUTHENTICATION,
     * TRIGGER_TYPE_PRE_CREATION, TRIGGER_TYPE_POST_CREATION, TRIGGER_TYPE_PRE_USERINFO_CREATION,
     * TRIGGER_TYPE_PRE_ACCESS_TOKEN_CREATION, TRIGGER_TYPE_PRE_SAML_RESPONSE_CREATION
     */
    triggerType: pulumi.Input<string>;
}
